@@ -21,7 +21,6 @@ from ..properties import Props
 
 from .raw import load_bitmap
 from .gdos import _subset_storable
-from .windows import _normalise_metrics
 
 
 _ID_MS = b'FONT   '
@@ -378,7 +377,10 @@ def _make_fit(fonts, codepage_prefix):
     fonts = (_make_one_fit(_font, codepage_prefix) for _font in fonts)
     fonts = tuple(_font for _font in fonts if _font)
     if not fonts:
-        raise FileFormatError('No storable fonts provided')
+        raise FileFormatError(
+            'CPI format can only store 8xN character-cell fonts'
+            ' encoded with a numbered codepage.'
+        )
     sizes = set(_f.cell_size for _f in fonts)
     codepages = sorted(set(_f.encoding for _f in fonts))
     # ensure all sizes exist for all codepages
@@ -406,7 +408,7 @@ def _make_one_fit(font, codepage_prefix):
     font = font.label(codepoint_from=font.encoding)
     # take only the glyphs that will fit
     font = _subset_storable(font, _RANGE)
-    font, _ = _normalise_metrics(font)
+    font = font.equalise_horizontal()
     font = _fill_contiguous(font, _RANGE, Glyph.blank(*font.cell_size))
     return font
 
