@@ -149,6 +149,8 @@ def save_psf(fonts, outstream, where=None):
         raise FileFormatError(
             'This format only supports character-cell fonts.'
         )
+    # fill out character cell including shifts, bearings and line height
+    font = font.equalise_horizontal()
     # ensure unicode labels exist if encoding is defined
     font = font.label()
     glyphs = font.glyphs
