@@ -641,7 +641,7 @@ def _make_contiguous(font, pix_width):
 
 def _normalise_metrics(font):
     """Normalise glyph representation for Windows."""
-    add_shift_up = max(0, -min(_g.shift_up for _g in font._glyphs))
+    add_shift_up = max(0, -min(_g.shift_up for _g in font.glyphs))
     ord_glyphs = tuple(
         _g.expand(
             # bring all glyphs to same height
